@@ -51,8 +51,7 @@ class DiscreteEnv(gym.Env):
     self.action_space = spaces.Discrete(n=2)
     
     #set OBSERVATION SPACE
-    #it is made of values for Xa, Xs, Y for each individual
-    #set three boxes
+    #it is made of values for Xa, Xs for each observation
     self.observation_space = spaces.Box(low=self.min_Xas, 
                                    high=self.max_Xas, 
                                    dtype=np.float32)
@@ -63,7 +62,7 @@ class DiscreteEnv(gym.Env):
 
     #set an initial state, sample a random row from df to get 1 observation (Xs(0), Xa(0))
     #the step def will update self.state according to some value
-    self.state=self.df.sample(n=1, random_state=1).to_numpy()
+    self.state=self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
     self.horizon=20
@@ -81,24 +80,24 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     #compute rho
-    Xsa=(self.thetas[0])+(self.thetas[1]*(self.state[0,0]))+(self.thetas[2]*(self.state[0,1]))
+    Xsa=(self.thetas[0])+(self.thetas[1])*(self.state[0])+(self.thetas[2])*(self.state[1])
     rho=(1/(1+np.exp(-Xsa)))
 
     #apply a value from the action space on the state by means of some function that depends on action
     #the function
-    g = ((1/2)*(3-(2*(rho)))*(self.state[0,1])+(1-(2*(rho)))*((1+(self.state[0,1])**2)**0.5))
+    g = ((1/2)*(3-(2*(rho)))*(self.state[1])+(1-(2*(rho)))*((1+(self.state[1])**2)**0.5))
 
     #if action is 1 and rho (risk) high, intervene and discount Xa
     if (action ==1) & (rho >= 0.5):
-        new_Xa = ((self.state[0,1])/0.9)
+        new_Xa = g
     else:
-        new_Xa = (self.state[0,1])  
+        new_Xa = (self.state[1])  
     #apply intervention on self.state
-    self.state[0,1] = new_Xa
+    self.state[1] = new_Xa
     
     
     #before setting the reward, predict Y_+1, as we have a new Xa
-    self.Y_new =+ 0 + (self.thetas[0])+(self.thetas[1])*(self.state[0,0])+(self.thetas[2])*(self.state[0,1])
+    self.Y_new =+ 0 + (self.thetas[0])+(self.thetas[1])*(self.state[0])+(self.thetas[2])*(self.state[1])
     #compute mean of Y (this is no longer 0-1 but a probability)
     self.Ynew_cumul = np.mean(self.Y_new)
     #reduce the horizon
@@ -120,7 +119,7 @@ class DiscreteEnv(gym.Env):
 
 #reset state and horizon    
   def reset(self):
-    self.state=self.df.sample(n=1, random_state=1).to_numpy()
+    self.state=self.df.sample(n=1, random_state=1).values.reshape(3,)
     self.horizon = 20
     return self.state
 
